starcluster.cli.StarClusterCLI

Package starcluster :: Module cli :: Class StarClusterCLI |
[hide private]
[frames] | no frames]

# Class StarClusterCLI

source code

StarCluster Command Line Interface

Instance Methods | [hide private]
get_description(self) | source code
parse_subcommands(self, gparser, subcmds) Parse given global arguments, find subcommand from given list of subcommand objects, parse local arguments and return a tuple of global options, selected command object, command options, and command arguments. | source code
create_global_parser(self) | source code
bug_found(self) | source code
main(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| gparser = `None` hash(x)
| subcmds_map = ``{``}``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### parse_subcommands(self, gparser, subcmds) | source code
Parse given global arguments, find subcommand from given list of subcommand objects, parse local arguments and return a tuple of global options, selected command object, command options, and command arguments. Call execute() on the command object to run. The command object has members 'gopts' and 'opts' set for global and command options respectively, you don't need to call execute with those but you could if you wanted to.